@@ -1,9 +1,10 @@
 package File::Dedup;
 # ABSTRACT: Deduplicate files across directories
-$File::Dedup::VERSION = '0.004';
+$File::Dedup::VERSION = '0.005';
 use strict;
 use warnings;
 
+use Data::Dumper;
 use Digest::MD5 qw(md5_hex);
 use feature qw(say);
 
@@ -107,7 +108,7 @@ sub _handle_duplicates {
          say "[ -1]\tSKIP";
          say "[C-c]\tQUIT";
          $to_keep = _get_numeric_response($number_of_files);
-         next if !$to_keep || $to_keep && $to_keep == -1;
+         next if ! defined $to_keep || defined $to_keep && $to_keep == -1;
       }
       else { # if ask = 0 keep the first duplicate
          $to_keep = 0;
@@ -124,13 +125,14 @@ sub _purge_files {
    my ($self, $files) = @_;
 
    foreach my $file ( @$files ) {
+      print "purging file: $file\n";
       my $response;
       if ( $self->ask ) { 
          do {
             print "About to delete '$file'; continue? [Y/n] ";
             $response = _prompt();
          }
-         while ( !grep { $response eq $_ } ('y', 'Y', '') );
+         while ( !grep { $response eq $_ } ('y', 'Y', 'n', 'N', '') );
       }
 
       _delete_file($file)
@@ -172,13 +174,14 @@ sub _get_numeric_response {
       }
    } while( !$valid_response );
 
+   print "AFTER get_numeric_response: $input\n";
    return $input;
 }
 
 sub _prompt {
-   my $input = <>;
+   my $input = <STDIN>;
    chomp($input);
-
+   
    return $input;
 }
 
@@ -223,7 +226,7 @@ File::Dedup - Deduplicate files across directories
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
